@@ -147,7 +147,8 @@ void GlossaryView::slotNewEntryDisplayed(DocPosition pos)
 
     QString sourceLangCode = Project::instance()->sourceLangCode();
     QList<QByteArray> termIds;
-    foreach (const QString& w, msg.split(m_rxSplit, Qt::SkipEmptyParts)) {
+    const auto ws = msg.split(m_rxSplit, Qt::SkipEmptyParts);
+    for (const QString& w : ws) {
         QString word = stem(sourceLangCode, w);
         QList<QByteArray> indexes = glossary.idsForLangWord(sourceLangCode, word);
         //if (indexes.size())
@@ -166,14 +167,17 @@ void GlossaryView::slotNewEntryDisplayed(DocPosition pos)
 
     bool found = false;
     //m_flowLayout->setEnabled(false);
-    foreach (const QByteArray& termId, QSet<QByteArray>(termIds.begin(), termIds.end())) {
+    const QSet<QByteArray> termIdSet(termIds.begin(), termIds.end());
+    for (const QByteArray& termId : termIdSet) {
         // now check which of them are really hits...
-        foreach (const QString& enTerm, glossary.terms(termId, sourceLangCode)) {
+        const auto enTerms = glossary.terms(termId, sourceLangCode);
+        for (const QString& enTerm : enTerms) {
             // ...and if so, which part of termEn list we must thank for match ...
             bool ok = msg.contains(enTerm); //,//Qt::CaseInsensitive  //we lowered terms on load
             if (!ok) {
                 QString enTermStemmed;
-                foreach (const QString& word, enTerm.split(m_rxSplit, Qt::SkipEmptyParts))
+                const auto words = enTerm.split(m_rxSplit, Qt::SkipEmptyParts);
+                for (const QString& word : words)
                     enTermStemmed += stem(sourceLangCode, word) + ' ';
                 ok = msgStemmed.contains(enTermStemmed);
             }
