@@ -73,8 +73,8 @@ void GlossaryTreeView::currentChanged(const QModelIndex& current, const QModelIn
 {
     if (current.isValid()) {
         //QModelIndex item=static_cast<QSortFilterProxyModel*>(model())->mapToSource(current);
-        //emit currentChanged(item.row());
-        emit currentChanged(modelIndexToId(current));
+        //Q_EMIT currentChanged(item.row());
+        Q_EMIT currentChanged(modelIndexToId(current));
         scrollTo(current);
     }
 }
@@ -350,8 +350,8 @@ void GlossaryWindow::showEntryInEditor(const QByteArray& id)
     Glossary* glossary = project->glossary();
     m_subjectField->setCurrentItem(glossary->subjectField(id),/*insert*/true);
 
-    QStringList langsToTry = QStringList(m_defLang) << QStringLiteral("en") << QStringLiteral("en_US") << project->targetLangCode();
-    foreach (const QString& lang, langsToTry) {
+    const QStringList langsToTry = QStringList(m_defLang) << QStringLiteral("en") << QStringLiteral("en_US") << project->targetLangCode();
+    for (const QString& lang : langsToTry) {
         QString d = glossary->definition(m_id, lang);
         if (!d.isEmpty()) {
             if (m_defLang != lang)
@@ -553,7 +553,8 @@ void TermListView::addTerm()
 
 void TermListView::rmTerms()
 {
-    foreach (const QModelIndex& row, selectionModel()->selectedRows())
+    const auto rows = selectionModel()->selectedRows();
+    for (const QModelIndex& row : rows)
         model()->removeRow(row.row());
 }
 
