@@ -116,7 +116,8 @@ void MsgCtxtView::process()
     if (m_tempNotes.contains(m_entry.entry)) {
         QString html = i18nc("@info notes to translation unit which expire when the catalog is closed", "<b>Temporary notes:</b>");
         html += MsgCtxtView::BR;
-        foreach (const QString& note, m_tempNotes.values(m_entry.entry))
+        const auto tempNotes = m_tempNotes.values(m_entry.entry);
+        for (const QString& note : tempNotes)
             html += note.toHtmlEscaped() + MsgCtxtView::BR;
         html += MsgCtxtView::BR;
         m_browser->insertHtml(html.replace('\n', MsgCtxtView::BR));
@@ -124,7 +125,8 @@ void MsgCtxtView::process()
     if (m_pologyNotes.contains(m_entry.entry)) {
         QString html = i18nc("@info notes generated by the pology check", "<b>Pology notes:</b>");
         html += MsgCtxtView::BR;
-        foreach (const QString& note, m_pologyNotes.values(m_entry.entry))
+        const auto pologyNotes = m_pologyNotes.values(m_entry.entry);
+        for (const QString& note : pologyNotes)
             html += note.toHtmlEscaped() + MsgCtxtView::BR;
         html += MsgCtxtView::BR;
         m_browser->insertHtml(html.replace('\n', MsgCtxtView::BR));
@@ -132,7 +134,8 @@ void MsgCtxtView::process()
     if (m_languageToolNotes.contains(m_entry.entry)) {
         QString html = i18nc("@info notes generated by the languagetool check", "<b>LanguageTool notes:</b>");
         html += MsgCtxtView::BR;
-        foreach (const QString& note, m_languageToolNotes.values(m_entry.entry))
+        const auto languageToolNotes = m_languageToolNotes.values(m_entry.entry);
+        for (const QString& note : languageToolNotes)
             html += note.toHtmlEscaped() + MsgCtxtView::BR;
         html += MsgCtxtView::BR;
         m_browser->insertHtml(html.replace('\n', MsgCtxtView::BR));
@@ -152,20 +155,21 @@ void MsgCtxtView::process()
 
     const QVector<Note> notes = m_catalog->notes(m_entry.toDocPosition());
     m_hasErrorNotes = false;
-    foreach (const Note& note, notes)
+    for (const Note& note : notes)
         m_hasErrorNotes = m_hasErrorNotes || note.content.contains(QLatin1String("[ERROR]"));
 
     int realOffset = displayNotes(m_browser, m_catalog->notes(m_entry.toDocPosition()), m_entry.form, m_catalog->capabilities()&MultipleNotes);
 
     QString html;
-    foreach (const Note& note, m_catalog->developerNotes(m_entry.toDocPosition())) {
+    const auto developerNotes = m_catalog->developerNotes(m_entry.toDocPosition());
+    for (const Note& note : developerNotes) {
         html += MsgCtxtView::BR + escapeWithLinks(note.content).replace('\n', BR);
     }
 
-    QStringList sourceFiles = m_catalog->sourceFiles(m_entry.toDocPosition());
+    const QStringList sourceFiles = m_catalog->sourceFiles(m_entry.toDocPosition());
     if (!sourceFiles.isEmpty()) {
         html += i18nc("@info PO comment parsing", "<br><b>Files:</b><br>");
-        foreach (const QString &sourceFile, sourceFiles)
+        for (const QString &sourceFile : sourceFiles)
             html += QString(QStringLiteral("<a href=\"src:/%1\">%2</a><br />")).arg(sourceFile, sourceFile);
         html.chop(6);
     }
@@ -220,7 +224,7 @@ void MsgCtxtView::pologyReceivedStandardOutput()
         }
         const QString grossPologyOutput = m_pologyProcess->readAllStandardOutput();
         const QStringList pologyTmpLines = grossPologyOutput.split('\n', Qt::SkipEmptyParts);
-        foreach (const QString pologyTmp, pologyTmpLines) {
+        for (const QString &pologyTmp : pologyTmpLines) {
             if (pologyTmp.startsWith(QStringLiteral("[note]")))
                 m_pologyData += pologyTmp;
         }
@@ -247,7 +251,7 @@ void MsgCtxtView::pologyHasFinished()
             if (pologyTmpLines.count() == 0) {
                 m_pologyData += i18nc("@info The pology command didn't return anything", "(empty)");
             } else {
-                foreach (const QString pologyTmp, pologyTmpLines) {
+                for (const QString &pologyTmp : pologyTmpLines) {
                     if (pologyTmp.startsWith(QStringLiteral("[note]")))
                         m_pologyData += pologyTmp;
                 }
@@ -294,7 +298,7 @@ void MsgCtxtView::anchorClicked(const QUrl& link)
         m_stackedLayout->setCurrentIndex(1);
     } else if (link.scheme() == QLatin1String("src")) {
         int pos = path.lastIndexOf(':');
-        emit srcFileOpenRequested(path.left(pos), path.midRef(pos + 1).toInt());
+        Q_EMIT srcFileOpenRequested(path.left(pos), path.midRef(pos + 1).toInt());
     } else if (link.scheme().contains(QLatin1String("tp")))
         QDesktopServices::openUrl(link);
 }
@@ -314,7 +318,7 @@ void MsgCtxtView::noteEditRejected()
 {
     m_stackedLayout->setCurrentIndex(0);
     m_unfinishedNotes.remove(m_entry);
-    emit escaped();
+    Q_EMIT escaped();
 }
 
 void MsgCtxtView::addNote(DocPosition p, const QString& text)
