@@ -56,7 +56,7 @@ RecursiveScanJob::RecursiveScanJob(const QString& dbName, QObject* parent)
 bool RecursiveScanJob::doKill()
 {
 #if QT_VERSION >= 0x050500
-    foreach (ScanJob* job, m_jobs)
+    for (ScanJob* job : qAsConst(m_jobs))
         TM::threadPool()->tryTake(job);
 #endif
     return true;
@@ -93,7 +93,7 @@ void RecursiveScanJob::scanJobDestroyed()
 void RecursiveScanJob::start()
 {
     m_time.start();
-    emit description(this,
+    Q_EMIT description(this,
                      i18n("Adding files to Lokalize translation memory"),
                      qMakePair(i18n("TM"), m_dbName));
 }
